==> grafana-enterprise_12.2.0-17311094888_17311094888_linux_arm-6.tar.gz: grafana-12.2.0-17311094888/public/app/extensions/query-library/QueryLibrary/QueryLibraryActions.tsx <==
import { css } from '@emotion/css';
import { useFormContext } from 'react-hook-form';

import { Trans, t } from '@grafana/i18n';
import { getAppEvents } from '@grafana/runtime';
import { Button, IconButton, Stack, Spinner, useStyles2 } from '@grafana/ui';
import { useQueryLibraryContext } from 'app/features/explore/QueryLibrary/QueryLibraryContext';

import { showDiscardAddQueryModal } from '..';
import { notifyApp } from '../../../core/actions';
import { createSuccessNotification } from '../../../core/copy/appNotification';
import { OnSelectQueryType } from '../../../features/explore/QueryLibrary/types';
import { dispatch } from '../../../store/store';
import { ShowConfirmModalEvent } from '../../../types/events';
import { useDeleteQueryMutation, useUpdateQueryMutation } from '../../api/clients/queries/v1beta1';
import { QueryLibraryInteractions } from '../QueryLibraryAnalyticsEvents';
import { selectors } from '../e2e-selectors/selectors';
import { QueryTemplateRow } from '../types';
import { canEditQuery } from '../utils/identity';

import { QueryDetails } from './QueryLibraryDetails';

export interface QueryLibraryActionsProps {
  onSelectQuery: OnSelectQueryType;
  selectedQueryRow: QueryTemplateRow;
  isEditingQuery: boolean;
  setIsEditingQuery: (isEditingQuery: boolean) => void;
  onEditQuerySuccess: (uid: string, isNew?: boolean) => void;
  isSavingLoading: boolean;
  usingHistory?: boolean;
}

export function QueryLibraryActions({
  onSelectQuery,
  selectedQueryRow,
  isEditingQuery,
  setIsEditingQuery,
  onEditQuerySuccess,
  usingHistory,
  isSavingLoading,
}: QueryLibraryActionsProps) {
  const styles = useStyles2(getStyles);
  const { setNewQuery } = useQueryLibraryContext();

  const [deleteQueryTemplate] = useDeleteQueryMutation();
  const [editQueryTemplate, { isLoading: isUpdateLoading }] = useUpdateQueryMutation();
  const { triggerAnalyticsEvent } = useQueryLibraryContext();

  const { isLocked } = selectedQueryRow;

  const {
    reset,
    formState: { isDirty },
  } = useFormContext<QueryDetails>();

  const onDeleteQuery = (queryUid: string) => {
    const performDelete = async (queryUid: string) => {
      QueryLibraryInteractions.deleteQueryClicked();
      await deleteQueryTemplate({
        name: queryUid,
      }).unwrap();
      dispatch(notifyApp(createSuccessNotification(t('query-library.notifications.query-deleted', 'Query deleted'))));
      triggerAnalyticsEvent(QueryLibraryInteractions.deleteQueryClicked);
    };

    getAppEvents().publish(
      new ShowConfirmModalEvent({
        title: t('query-library.delete-modal.title', 'Delete query'),
        text: t(
          'query-library.delete-modal.body-text',
          "You're about to remove this saved query. This action cannot be undone. Do you want to continue?"
        ),
        yesText: t('query-library.delete-modal.confirm-button', 'Delete query'),
        icon: 'trash-alt',
        onConfirm: () => performDelete(queryUid),
      })
    );
  };

  const onDuplicateQuery = () => {
    triggerAnalyticsEvent(QueryLibraryInteractions.duplicateQueryClicked);
    setNewQuery({
      ...selectedQueryRow,
      uid: undefined,
      title: `${selectedQueryRow.title} ${t('query-library.actions.duplicate-query-title-copy', 'Copy')}`,
    });
    setIsEditingQuery(true);
  };

  const onAddHistoryQueryToLibrary = () => {
    setNewQuery({
      ...selectedQueryRow,
      uid: undefined,
      title: t('explore.query-library.default-title', 'New query'),
    });
    setIsEditingQuery(true);
    triggerAnalyticsEvent(QueryLibraryInteractions.saveRecentQueryClicked);
  };

  const onLockToggle = async () => {
    if (!selectedQueryRow.uid) {
      return;
    }
    triggerAnalyticsEvent(QueryLibraryInteractions.lockQueryClicked, {
      isLocked: !isLocked,
    });
    await editQueryTemplate({
      name: selectedQueryRow.uid || '',
      patch: {
        spec: {
          isLocked: !isLocked,
        },
      },
    }).unwrap();

    onEditQuerySuccess(selectedQueryRow.uid);
  };

  if (usingHistory) {
    return (
      <Stack width="100%" justifyContent="flex-end">
        <Button data-testid={selectors.components.queryLibraryDrawer.confirm} onClick={onAddHistoryQueryToLibrary}>
          <Trans i18nKey="query-library.actions.save-history-query-button">Save query</Trans>
        </Button>
      </Stack>
    );
  }
  const resetForm = () => {
    reset();
    if (!selectedQueryRow.uid) {
      QueryLibraryInteractions.cancelSaveNewQueryClicked();
      setNewQuery(undefined);
    } else {
      QueryLibraryInteractions.cancelEditClicked();
    }
    setIsEditingQuery(false);
  };

  const onCancelEditClick = () => {
    if (isDirty) {
      showDiscardAddQueryModal(resetForm);
    } else {
      resetForm();
    }
  };

  return (
    <Stack wrap="wrap" justifyContent="space-between">
      {selectedQueryRow.uid && (
        <Stack wrap="wrap" justifyContent="flex-start" alignItems="center">
          <IconButton
            data-testid={selectors.components.queryLibraryDrawer.delete}
            variant="secondary"
            name="trash-alt"
            onClick={() => onDeleteQuery(selectedQueryRow.uid ?? '')}
            tooltip={t('query-library.actions.delete-query-button', 'Delete query')}
            disabled={selectedQueryRow.isLocked || !canEditQuery(selectedQueryRow)}
          />
          <IconButton
            data-testid={selectors.components.queryLibraryDrawer.lock}
            variant={isLocked ? 'primary' : 'secondary'}
            name={isLocked ? 'lock' : 'unlock'}
            onClick={onLockToggle}
            tooltip={
              isLocked
                ? t('query-library.actions.unlock-query-button', 'Unlock query')
                : t('query-library.actions.lock-query-button', 'Lock query')
            }
            disabled={!canEditQuery(selectedQueryRow) || isEditingQuery}
          />
          <IconButton
            data-testid={selectors.components.queryLibraryDrawer.duplicate}
            variant="secondary"
            name="copy"
            onClick={onDuplicateQuery}
            tooltip={t('query-library.actions.duplicate-query-button', 'Duplicate query')}
          />
          {isUpdateLoading && <Spinner />}
        </Stack>
      )}
      {isEditingQuery || !selectedQueryRow.uid ? (
        <div className={styles.editActionsContainer}>
          <Stack alignItems="center">
            <Button variant="secondary" onClick={onCancelEditClick}>
              <Trans i18nKey="explore.query-library.cancel">Cancel</Trans>
            </Button>
            <Button
              variant="primary"
              type="submit"
              disabled={(!isDirty && !!selectedQueryRow.uid) || isSavingLoading}
              icon={isSavingLoading ? 'spinner' : undefined}
              data-testid={selectors.components.queryLibraryDrawer.saveQueryButton}
            >
              {isSavingLoading
                ? t('explore.query-library.saving', 'Saving...')
                : t('explore.query-library.save', 'Save')}
            </Button>
          </Stack>
        </div>
      ) : (
        <Button
          data-testid={selectors.components.queryLibraryDrawer.confirm}
          onClick={() => onSelectQuery(selectedQueryRow.query)}
        >
          <Trans i18nKey="query-library.actions.select-query-button">Select query</Trans>
        </Button>
      )}
    </Stack>
  );
}

const getStyles = () => {
  return {
    editActionsContainer: css({
      marginLeft: 'auto',
    }),
  };
};

==> grafana-enterprise_12.3.0-18546308611_18546308611_linux_arm-6.tar.gz: grafana-12.3.0-18546308611/public/app/extensions/query-library/QueryLibrary/QueryLibraryActions.tsx <==
import { css } from '@emotion/css';
import { useFormContext } from 'react-hook-form';

import { Trans, t } from '@grafana/i18n';
import { Button, Stack, useStyles2 } from '@grafana/ui';
import { useQueryLibraryContext } from 'app/features/explore/QueryLibrary/QueryLibraryContext';
import { SavedQuery } from 'app/features/explore/QueryLibrary/types';

import { showDiscardAddQueryModal } from '..';
import { QueryLibraryInteractions } from '../QueryLibraryAnalyticsEvents';
import { selectors } from '../e2e-selectors/selectors';
import { canEditQuery } from '../utils/identity';
import { hasUnresolvedVariables } from '../utils/templateVariables';

import { QueryDetails } from './QueryLibraryDetails';
import { QueryLibraryMenuActions } from './QueryLibraryMenuActions';

export interface QueryLibraryActionsProps {
  selectedQueryRow: SavedQuery;
  isEditingQuery: boolean;
  setIsEditingQuery: (isEditingQuery: boolean) => void;
  isSavingLoading: boolean;
  usingHistory?: boolean;
  onEditQuerySuccess: (uid: string, isNew?: boolean) => void;
}

export function QueryLibraryActions({
  selectedQueryRow,
  isEditingQuery,
  setIsEditingQuery,
  usingHistory,
  isSavingLoading,
  onEditQuerySuccess,
}: QueryLibraryActionsProps) {
  const styles = useStyles2(getStyles);
  const { setNewQuery, context, triggerAnalyticsEvent, closeDrawer, onSelectQuery } = useQueryLibraryContext();

  const hasTemplateVariables = hasUnresolvedVariables(selectedQueryRow.query);

  const {
    reset,
    formState: { isDirty },
  } = useFormContext<QueryDetails>();

  const onAddHistoryQueryToLibrary = () => {
    setNewQuery({
      ...selectedQueryRow,
      uid: undefined,
      title: t('explore.query-library.default-title', 'New query'),
    });
    setIsEditingQuery(true);
    triggerAnalyticsEvent(QueryLibraryInteractions.saveRecentQueryClicked);
  };

  if (usingHistory) {
    return (
      <Stack width="100%" justifyContent="flex-end">
        <Button data-testid={selectors.components.queryLibraryDrawer.confirm} onClick={onAddHistoryQueryToLibrary}>
          <Trans i18nKey="query-library.actions.save-history-query-button">Save query</Trans>
        </Button>
      </Stack>
    );
  }

  const resetForm = () => {
    reset();
    if (!selectedQueryRow.uid) {
      QueryLibraryInteractions.cancelSaveNewQueryClicked();
      setNewQuery(undefined);
    } else {
      QueryLibraryInteractions.cancelEditClicked();
    }
    setIsEditingQuery(false);
  };

  const onCancelEditClick = () => {
    if (isDirty) {
      showDiscardAddQueryModal(resetForm);
    } else {
      resetForm();
    }
    // Closing the drawer if not in explore or panel editor
    if (context === 'unknown') {
      closeDrawer();
    }
  };

  let saveButtonText = '';
  if (isSavingLoading) {
    saveButtonText = t('explore.query-library.saving', 'Saving...');
  } else if (context === 'unknown') {
    saveButtonText = t('explore.query-library.save-and-close', 'Save and close');
  } else {
    saveButtonText = t('explore.query-library.save', 'Save');
  }

  return (
    <Stack wrap="wrap" justifyContent="end">
      {isEditingQuery || !selectedQueryRow.uid ? (
        <div className={styles.editActionsContainer}>
          <Stack alignItems="center">
            <Button variant="secondary" onClick={onCancelEditClick}>
              <Trans i18nKey="explore.query-library.cancel">Cancel</Trans>
            </Button>
            <Button
              variant="primary"
              type="submit"
              disabled={(!isDirty && !!selectedQueryRow.uid) || isSavingLoading || !canEditQuery(selectedQueryRow)}
              icon={isSavingLoading ? 'spinner' : undefined}
              data-testid={selectors.components.queryLibraryDrawer.saveQueryButton}
            >
              {saveButtonText}
            </Button>
          </Stack>
        </div>
      ) : (
        <>
          <QueryLibraryMenuActions
            selectedQueryRow={selectedQueryRow}
            setIsEditingQuery={setIsEditingQuery}
            onEditQuerySuccess={onEditQuerySuccess}
          />
          <Button
            data-testid={selectors.components.queryLibraryDrawer.confirm}
            disabled={hasTemplateVariables && context === 'explore'}
            onClick={() => {
              onSelectQuery(selectedQueryRow.query);
              //close drawer
              closeDrawer(true, false);
              // trigger analytics event
              triggerAnalyticsEvent(QueryLibraryInteractions.selectQueryClicked);
            }}
          >
            <Trans i18nKey="query-library.actions.select-query-button">Select query</Trans>
          </Button>
        </>
      )}
    </Stack>
  );
}

const getStyles = () => {
  return {
    editActionsContainer: css({
      marginLeft: 'auto',
    }),
  };
};
